@@ -4,8 +4,7 @@ import logging
 import traceback
 
 from ...codebase import downloader, extractors
-from . import banner, constants, decorators, intelliq, prompts, special
-from .player import handle_streamer
+from . import banner, constants, decorators, intelliq, player, prompts, special
 from .processors import process_query, provider_searcher_mapping
 
 fe_logger = logging.getLogger("further-extraction")
