@@ -1,5 +1,4 @@
 import json
-import logging
 import time
 from base64 import b64decode, b64encode
 from functools import partial
@@ -10,8 +9,6 @@ import yarl
 
 from .hardstream import get_hardstream_generator, hard_urls
 
-animixplay_logger = logging.getLogger("provider:animixplay")
-
 ID_MATCHER = regex.compile(r"\?id=([^&]+)")
 EMBED_URL_BASE = "https://animixplay.to/api/live"
 EMBED_M3U8_MATCHER = regex.compile(r"player\.html?[^#]*#([^#]+)")
@@ -28,23 +25,15 @@ URL_ALIASES = {
 def url_update(url):
     for key, item in URL_ALIASES.items():
         if key in url:
-            animixplay_logger.debug(
-                "Replacing {!r} to {!r} in {!r}.".format(key, item, url)
-            )
             url = url.replace(key, item)
     return url
 
 
 def extract_from_url(embed_url):
-    
+
     on_url = EMBED_M3U8_MATCHER.search(embed_url) or EMBED_B64_MATCHER.search(embed_url)
 
     if not on_url:
-        animixplay_logger.debug(
-            "Failed to find stream on {!r}, will fallback to API based m3u8.".format(
-                embed_url
-            )
-        )
         return []
 
     return [{"stream_url": url_update(b64decode(on_url.group(1)).decode())}]
@@ -63,9 +52,6 @@ def extract_from_embed(session, embed_url):
     on_site = EMBED_VIDEO_MATCHER.search(embed_page.text)
 
     if on_site:
-        animixplay_logger.debug(
-            "Regex matched a video on the site: {!r}, extracting.".format(on_site)
-        )
         return extract_from_url(on_site.group(1))
 
     return extract_from_url(str(embed_page.url))
